//
//  ChartData.swift
//  FLCharts
//
//  Created by Francesco Leoni on 11/01/22.
//  Copyright © 2021 Francesco Leoni All rights reserved.
//

import UIKit

public struct ChartData: Equatable {
    
    /// The title of the chart.
    public var title: String
    
    /// The data of a specific bar.
    public var barData: [BarData]
    
    /// The keys of the legend. On multi-value bars the first key corresponds to the lower part of the bar.
    public var legendKeys: [Key]
    
    /// The unit of measure to apply to the value of the bar.
    public var unitOfMeasure: String
    
    /// The bar with the higher compound value.
    public var maxBarData: BarData? {
        barData.max(by: { $0.total < $1.total })
    }
    
    /// The y delta that specifies the y axis granulation if the user doesn't provide one.
    public var defaultYDelta: CGFloat {
        floor((maxBarData?.total ?? 100) / 3)
    }
    
    /// The average value of the chart.
    public var average: CGFloat {
        let sumArray = barData.reduce(0) { sum, newValue -> CGFloat in
            var sum = sum
            sum += newValue.total
            return sum
        }

        return sumArray / CGFloat(barData.count)
    }
    
    public var formattedAverage: String {
        Formatters.toDecimals(value: NSNumber(value: average)) ?? "N/D"
    }
    
    // MARK: - Init
    
    public init(title: String, barData: [BarData], legendKeys: [Key], unitOfMeasure: String) {
        self.title = title
        self.barData = barData
        self.legendKeys = legendKeys
        self.unitOfMeasure = unitOfMeasure
    }
}
